#!/usr/bin/ksh

# --------------------------------------------------------------------------
# Resets SSH keys on the endpoint.
#
# @return
#	result=success
#			Overall operation succeed.
#
#	result=fail
#			Overall operation failed. More details given in ssh_RC below.
#
#	ssh_RC={notfound, key_gen_fail, start_fail, stop_fail}
#
#	ssh_RC=notfound
#			The service command was not found on this endpoint
#
#	ssh_RC=key_gen_fail
#			A failure occurred while re-generating SSH keys
#
#	ssh_RC=start_fail
#			A failure occurred when starting the service
#
#	ssh_RC=stop_fail
#			A failure occurred when stopping the service
#
# ---------------------------------------------------------------------------

#---------------------------------------------------------------------------
# Utility function to wait for the specified subsystem to stop.
#
#	@param susbsystem service name
#	@return 0 subsystem reported as stopped during the predefined elapsed 
#	time
#	@return 1 subsystem not being reported stopped during the predefined
#	elapsed time
#
#---------------------------------------------------------------------------
function wait_for_service_to_stop {
	
	for i in 1 2 3 4 5 6 7 8 9 10
	do
		sleep 5
		/usr/bin/lssrc -s $1 | grep -i inoperative  >/dev/null 2>&1
		res=$?
		if [ "$res" = "0" ]; then
			break
		else
			echo "dummy" > /dev/null
		fi
		if [ "$i" = "10" ]; then
			return 1
		fi
	done
	
	return 0
}

# -----------------------------------------------
# Fail if can not locate the SSH sub system
# -----------------------------------------------
/usr/bin/lssrc -s sshd > /dev/null 2>&1
RC=$?

if [ "$RC" != "0" ]; then
	echo "result=fail,ssh_RC=notfound"
	exit 0
fi

# -----------------------------------------------
# Stop the service in any case. Don't check RC
# -----------------------------------------------
/usr/bin/stopsrc -s sshd > /dev/null 2>&1
wait_for_service_to_stop "sshd"
RC=$?
if [ "$RC" != "0" ]; then
	echo "result=fail,ssh_RC=stop_fail"
	exit 0;
fi

# -----------------------------------------------
# Remove the keys
# -----------------------------------------------
/usr/bin/rm -f /etc/ssh/ssh_host_key
/usr/bin/rm -f /etc/ssh/ssh_host_rsa_key
/usr/bin/rm -f /etc/ssh/ssh_host_dsa_key

# -----------------------------------------------
# Regenerate the keys
# -----------------------------------------------
/usr/bin/ssh-keygen -f /etc/ssh/ssh_host_key -N '' -t rsa1 > /dev/null 2>&1
RC=$?
if [ "$RC" != "0" ]; then
	echo "result=fail,ssh_RC=key_gen_fail"
	/usr/bin/startsrc -s sshd > /dev/null 2>&1
	exit 0
fi

/usr/bin/ssh-keygen -f /etc/ssh/ssh_host_rsa_key -N '' -t rsa > /dev/null 2>&1
RC=$?

if [ "$RC" != "0" ]; then
	echo "result=fail,ssh_RC=key_gen_fail"
	/usr/bin/startsrc -s sshd > /dev/null 2>&1
	exit 0
fi

/usr/bin/ssh-keygen -f /etc/ssh/ssh_host_dsa_key -N '' -t dsa > /dev/null 2>&1
RC=$?

if [ "$RC" != "0" ]; then
	echo "result=fail,ssh_RC=key_gen_fail"
	/usr/bin/startsrc -s sshd > /dev/null 2>&1
	exit 0
fi

# -----------------------------------------------
# Start the service
# -----------------------------------------------
/usr/bin/startsrc -s sshd > /dev/null 2>&1
RC=$?

if [ "$RC" != "0" ]; then
	echo "result=fail,ssh_RC=start_fail"
	exit 0
fi

echo "result=success"
